"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.andOperator = exports.orOperator = exports.neqOperator = exports.eqOperator = exports.ifOperator = void 0;
var lodash_1 = require("lodash");
var validators_1 = require("./validators");
exports.ifOperator = {
    name: 'if',
    description: 'Check if a condition is truthy',
    argsValidator: validators_1.logicalSingleConditionValidator,
    handler: function (_a) {
        var condition = _a.condition;
        var c = condition[0];
        return !!c;
    },
};
exports.eqOperator = {
    name: 'eq',
    description: 'Checks if the comparators are deep equal',
    argsValidator: validators_1.logicalCompararisonsValidator,
    handler: function (_a) {
        var comparison = _a.comparison;
        var c1 = comparison[0], c2 = comparison[1];
        return lodash_1.isEqual(c1, c2);
    },
};
exports.neqOperator = {
    name: 'neq',
    description: 'Checks if the comparators are not deep equal',
    argsValidator: validators_1.logicalCompararisonsValidator,
    handler: function (_a) {
        var comparison = _a.comparison;
        var c1 = comparison[0], c2 = comparison[1];
        return !lodash_1.isEqual(c1, c2);
    },
};
exports.orOperator = {
    name: 'or',
    description: 'Checks if any of the conditions are truthy',
    argsValidator: validators_1.logicalUnlimitedConditionsValidator,
    handler: function (_a) {
        var conditions = _a.conditions;
        return conditions.some(function (condition) { return !!condition; });
    },
};
exports.andOperator = {
    name: 'and',
    description: 'Checks if any of all the provided conditions are truthy',
    argsValidator: validators_1.logicalUnlimitedConditionsValidator,
    handler: function (_a) {
        var conditions = _a.conditions;
        return conditions.every(function (condition) { return !!condition; });
    },
};
